@@ -1,5 +1,6 @@
 # coding=utf-8
 from .._impl import (
+    ingest_workflow_api_CreateIngestJobRequest as CreateIngestJobRequest,
     ingest_workflow_api_Empty as Empty,
     ingest_workflow_api_EnsureExtractorJobCreatedRequest as EnsureExtractorJobCreatedRequest,
     ingest_workflow_api_EnsureExtractorJobCreatedResponse as EnsureExtractorJobCreatedResponse,
@@ -30,6 +31,7 @@ from .._impl import (
 )
 
 __all__ = [
+    'CreateIngestJobRequest',
     'Empty',
     'EnsureExtractorJobCreatedRequest',
     'EnsureExtractorJobCreatedResponse',
