@@ -131,7 +131,10 @@ from .._impl import (
     scout_chartdefinition_api_Position as Position,
     scout_chartdefinition_api_ProcedureVizDefinition as ProcedureVizDefinition,
     scout_chartdefinition_api_ProcedureVizDefinitionV1 as ProcedureVizDefinitionV1,
+    scout_chartdefinition_api_ProcedureVizDefinitionV2 as ProcedureVizDefinitionV2,
     scout_chartdefinition_api_ProcedureVizDefinitionVisitor as ProcedureVizDefinitionVisitor,
+    scout_chartdefinition_api_ProcedureVizId as ProcedureVizId,
+    scout_chartdefinition_api_ProcedureVizIdVisitor as ProcedureVizIdVisitor,
     scout_chartdefinition_api_RangeCellConfig as RangeCellConfig,
     scout_chartdefinition_api_RangeGroupBySort as RangeGroupBySort,
     scout_chartdefinition_api_RangeGroupBySortVisitor as RangeGroupBySortVisitor,
@@ -327,6 +330,9 @@ __all__ = [
     'ProcedureVizDefinition',
     'ProcedureVizDefinitionVisitor',
     'ProcedureVizDefinitionV1',
+    'ProcedureVizDefinitionV2',
+    'ProcedureVizId',
+    'ProcedureVizIdVisitor',
     'RangeCellConfig',
     'RangeGroupBySort',
     'RangeGroupBySortVisitor',
