@@ -212,7 +212,6 @@ from .._impl import (
     scout_compute_api_MinMaxThresholdRanges as MinMaxThresholdRanges,
     scout_compute_api_MinSeries as MinSeries,
     scout_compute_api_Minimum as Minimum,
-    scout_compute_api_ModuleApplicationDerivedSeries as ModuleApplicationDerivedSeries,
     scout_compute_api_ModuleVersionReference as ModuleVersionReference,
     scout_compute_api_ModuleVersionReferenceVisitor as ModuleVersionReferenceVisitor,
     scout_compute_api_NegativeValueConfiguration as NegativeValueConfiguration,
@@ -591,7 +590,6 @@ __all__ = [
     'MinMaxThresholdRanges',
     'MinSeries',
     'Minimum',
-    'ModuleApplicationDerivedSeries',
     'ModuleVersionReference',
     'ModuleVersionReferenceVisitor',
     'NegativeValueConfiguration',
